<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Client Jabber/XMPP senzill i fàcil d&apos;usar</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Llicència:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Vegeu el codi font en línia</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Informeu de problemes</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete account completely</source>
        <translation type="vanished">Suprimeix el compte completament</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Suprimeix</translation>
    </message>
</context>
<context>
    <name>AccountDeletionPage</name>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Suprimeix el compte</translation>
    </message>
    <message>
        <source>Delete completely</source>
        <translation type="vanished">Suprimeix completament</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow to add additional devices using the login QR code but never show the password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Transfereix el compte a un altre dispositiu</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Escanegeu el codi QR o introduïu les credencials com a text en un altre dispositiu per a iniciar-hi una sessió.

Atenció:
Mai no mostreu aquest codi QR als altres. Fer-ho donaria accés il·limitat al vostre compte!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Adreça del xat:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Amaga el codi QR</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Mostra com a codi QR</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Amaga el text</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Mostra com a text</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy chat address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Canvia la contrasenya</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Contrasenya actual:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Contrasenya nova:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Contrasenya nova (de nou):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Les contrasenyes noves no coincideixen.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>La contrasenya actual no és vàlida.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Heu de connectar-vos per a canviar la contrasenya.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Després de canviar la contrasenya, haureu de tornar a introduir-la a tots els altres dispositius.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Canvia</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="unfinished">No s’ha pogut canviar la contrasenya: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Copia el missatge</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Edita el missatge</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Revelació</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation type="unfinished">Copia el missatge</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="unfinished">Edita el missatge</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="unfinished">Copia l’URL de la baixada</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="unfinished">Cita el missatge</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Crea un missatge</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Imatge</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vídeo</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Àudio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Document</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Un altre fitxer</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Selecciona un fitxer</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Envia una revelació</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Indici de la revelació</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Torna a activar les notificacions</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Silencia les notificacions</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Mostra el perfil</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Tanca</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Cerca cap enrere</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Cerca cap endavant</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">Tots els fitxers</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="vanished">Copia el missatge</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="vanished">Edita el missatge</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Copia l’URL de la baixada</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="vanished">Cita el missatge</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation type="unfinished">Indici de la revelació</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation type="unfinished">Crea un missatge</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Very high</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Qualitat constant</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished">Canvia</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel·la</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Don&apos;t expose your password in any way</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Don&apos;t show your password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be shown anymore but still exposed via the login QR code.
You won&apos;t be able to see your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>El fitxer %1 no s&apos;ha pogut desar</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Ha fallat la baixada: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Preferits</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Gent</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Natura</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Menjar</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Activitat</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Viatges</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Objectes</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Símbols</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Banderes</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Cerca</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Cerca emojis</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Seleccioneu un xat per a començar</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Seleccioneu un fitxer</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Vés a la carpeta superior</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Tanca</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="vanished">Surt</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Invita amistats</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>S&apos;ha copiat l&apos;enllaç d&apos;invitació al porta-retalls</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">Fora de línia</translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>S’està connectant…</translation>
    </message>
    <message>
        <source>Transfer account</source>
        <translation type="vanished">Transfereix el compte</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Suprimeix el compte</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>L&apos;enllaç s&apos;obrirà després de que us hagueu connectat.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>Entra</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Entreu amb el vostre compte XMPP</translation>
    </message>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">El vostre ID de Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">usuari@exemple.org</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">La vostra contrasenya:</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>S’està connectant…</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Connecta</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Usuari o contrasenya invàlids.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">No s&apos;ha pogut connectar al servidor. Comproveu la vostra connexió a internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">El servidor no és compatible amb connexions segures.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">S&apos;ha produït un error provant de connectar de forma segura.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">No s&apos;ha pogut resoldre l&apos;adreça del servidor. Torneu a comprovar el vostre IDJ.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">No s&apos;ha pogut connectar al servidor.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Protocol d&apos;autenticació no compatible amb el servidor.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">S&apos;ha produït un error desconegut. Vegeu el registre per més detalls.</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Fes una foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Enregistra un vídeo</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Enregistra la veu</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Envia la ubicació</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Tria un fitxer</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Tria una imatge</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Tria un vídeo</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Tria un fitxer d’àudio</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Tria un document</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tots els fitxers</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Fitxers d’àudio</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Àudio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished">Document</translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">Imatge</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">Vídeo</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished">Fitxer</translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">No s&apos;ha pogut enviar el missatge perquè no teniu connexió.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">No s&apos;ha pogut corregir el missatge perquè no teniu connexió.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Revelació</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>No s’ha pogut enviar el missatge.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>La correcció del missatge no ha anat bé.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Configuració de multimèdia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Captura d’imatges</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Enregistrament d’àudio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Enregistrament de vídeo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Entrada d’àudio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Contenidor</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Imatge</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Còdec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolució</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualitat</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Freqüència de mostratge</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Freqüència dels fotogrames</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Preparat</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>S’està inicialitzant…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>S’està enregistrant…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Image</source>
        <translation type="obsolete">Imatge</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Àudio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="obsolete">Vídeo</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation type="vanished">Preparat</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>S’està inicialitzant…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>S’està enregistrant… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished">Disponible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="unfinished">Lliure per xatejar</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished">Lluny</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="unfinished">No em molesteu</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="unfinished">He sortit una estona</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">Fora de línia</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="vanished">Disponible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="obsolete">Lliure per xatejar</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Lluny</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">No em molesteu</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">He sortit una estona</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="obsolete">Fora de línia</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Error</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>El nom d’usuari o la contrasenya són incorrectes.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>No s’ha pogut connectar al servidor. Comproveu la vostra connexió a internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>El servidor no és compatible amb les connexions segures.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>S’ha produït un error en provar de connectar de forma segura.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">No s&apos;ha pogut connectar al servidor.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>El protocol d’autenticació no és compatible amb el servidor.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is typing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 paused typing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This QR code is not a valid login QR code.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">La contrasenya s&apos;ha canviat correctament.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">No s’ha pogut canviar la contrasenya: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation type="unfinished">Suprimeix el compte completament</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Afegeix un contacte nou</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Això també enviarà una petició d&apos;accés la disponibilitat del contacte.</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>ID Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>usuari@exemple.org</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Àlies:</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Missatge opcional:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Digueu al vostre interlocutor/a qui sou.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="vanished">Error: Comproveu el IDJ.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Disponible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Lliure per xatejar</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Lluny</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">No em molesteu</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">He sortit una estona</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Fora de línia</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Error</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>No s&apos;ha pogut afegir el contacte perquè no hi ha connexió.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>No s&apos;ha pogut eliminar el contacte perquè no hi ha connexió.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Filtració</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation>Connectant…</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>Contactes</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Afegeix un nou contacte</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fora de línia</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="vanished">Segur que voleu eliminar el contacte &lt;b&gt;%1&lt;/b&gt; de la vostra llista?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Elimina el contacte</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation>Llegenda</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envia</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Canvia la contrasenya</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Canvia la contrasenya del vostre compte. Haureu de tornar a introduir-la als altres dispositius.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished">Configuració de multimèdia</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Configuració</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished">Suprimeix el compte</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on another device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Canvia la contrasenya</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Canvia la contrasenya del vostre compte. Haureu de tornar a introduir-la als altres dispositius.</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Configuració</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Petició de subscripció</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Heu rebut una petició de subscripció de &lt;b&gt;%1&lt;/b&gt;. Si l&apos;acceptau, aquest compte tendrà accés al vostre estat de dispobibilitat.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Rebutja</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Accepta</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>No s&apos;ha pogut enviar el fitxer perquè no hi ha connexió.</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Fitxer</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished">No s’ha pogut enviar el missatge.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Perfil</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correu-e</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Aniversari</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Lloc web</translation>
    </message>
</context>
</TS>
